@@ -1,14 +1,17 @@
 # ambivo_agents/agents/__init__.py
+from .analytics import AnalyticsAgent
+from .api_agent import APIAgent
 from .assistant import AssistantAgent
 from .code_executor import CodeExecutorAgent
 from .knowledge_base import KnowledgeBaseAgent
-from .web_search import WebSearchAgent
-from .web_scraper import WebScraperAgent
 from .media_editor import MediaEditorAgent
-from .youtube_download import YouTubeDownloadAgent
 from .moderator import ModeratorAgent
+from .web_scraper import WebScraperAgent
+from .web_search import WebSearchAgent
+from .youtube_download import YouTubeDownloadAgent
 
 __all__ = [
+    "AnalyticsAgent",
     "AssistantAgent",
     "CodeExecutorAgent",
     "KnowledgeBaseAgent",
@@ -16,6 +19,6 @@ __all__ = [
     "WebScraperAgent",
     "MediaEditorAgent",
     "YouTubeDownloadAgent",
-    "ModeratorAgent"
+    "ModeratorAgent",
+    "APIAgent",
 ]
-
