@@ -1,4 +1,4 @@
 # ambivo_agents/config/__init__.py
-from .loader import load_config, ConfigurationError
+from .loader import ConfigurationError, load_config
 
 __all__ = ["load_config", "ConfigurationError"]
