@@ -4,18 +4,18 @@ Enhanced BaseAgent with built-in auto-context session management and simplified
 """
 
 import asyncio
-import uuid
-import time
-import tempfile
+import logging
 import os
-from pathlib import Path
+import tempfile
+import time
+import uuid
 from abc import ABC, abstractmethod
+from concurrent.futures import ThreadPoolExecutor
 from dataclasses import dataclass, field
 from datetime import datetime, timedelta
 from enum import Enum
-from typing import Dict, List, Any, Optional, Callable, Tuple, Union, AsyncIterator
-from concurrent.futures import ThreadPoolExecutor
-import logging
+from pathlib import Path
+from typing import Any, AsyncIterator, Callable, Dict, List, Optional, Tuple, Union
 
 # Docker imports
 try:
@@ -61,30 +61,30 @@ class AgentMessage:
     def to_dict(self) -> Dict[str, Any]:
         """Convert to dictionary for serialization"""
         return {
-            'id': self.id,
-            'sender_id': self.sender_id,
-            'recipient_id': self.recipient_id,
-            'content': self.content,
-            'message_type': self.message_type.value,
-            'metadata': self.metadata,
-            'timestamp': self.timestamp.isoformat(),
-            'session_id': self.session_id,
-            'conversation_id': self.conversation_id
+            "id": self.id,
+            "sender_id": self.sender_id,
+            "recipient_id": self.recipient_id,
+            "content": self.content,
+            "message_type": self.message_type.value,
+            "metadata": self.metadata,
+            "timestamp": self.timestamp.isoformat(),
+            "session_id": self.session_id,
+            "conversation_id": self.conversation_id,
         }
 
     @classmethod
-    def from_dict(cls, data: Dict[str, Any]) -> 'AgentMessage':
+    def from_dict(cls, data: Dict[str, Any]) -> "AgentMessage":
         """Create from dictionary"""
         return cls(
-            id=data['id'],
-            sender_id=data['sender_id'],
-            recipient_id=data.get('recipient_id'),
-            content=data['content'],
-            message_type=MessageType(data['message_type']),
-            metadata=data.get('metadata', {}),
-            timestamp=datetime.fromisoformat(data['timestamp']),
-            session_id=data.get('session_id'),
-            conversation_id=data.get('conversation_id')
+            id=data["id"],
+            sender_id=data["sender_id"],
+            recipient_id=data.get("recipient_id"),
+            content=data["content"],
+            message_type=MessageType(data["message_type"]),
+            metadata=data.get("metadata", {}),
+            timestamp=datetime.fromisoformat(data["timestamp"]),
+            session_id=data.get("session_id"),
+            conversation_id=data.get("conversation_id"),
         )
 
 
@@ -113,6 +113,7 @@ class AgentContext:
     Built-in context for every BaseAgent instance
     Automatically created when agent is instantiated
     """
+
     session_id: str
     conversation_id: str
     user_id: str
@@ -128,7 +129,7 @@ class AgentContext:
             conversation_id=self.conversation_id,
             user_id=self.user_id,
             tenant_id=self.tenant_id,
-            metadata=self.metadata
+            metadata=self.metadata,
         )
 
     def update_metadata(self, **kwargs):
@@ -142,6 +143,7 @@ class AgentContext:
 @dataclass
 class ProviderConfig:
     """Configuration for LLM providers"""
+
     name: str
     model_name: str
     priority: int
@@ -202,8 +204,9 @@ class ProviderTracker:
         provider = self.providers[provider_name]
 
         if not provider.is_available:
-            if (provider.last_error_time and
-                    datetime.now() - provider.last_error_time > timedelta(minutes=provider.cooldown_minutes)):
+            if provider.last_error_time and datetime.now() - provider.last_error_time > timedelta(
+                minutes=provider.cooldown_minutes
+            ):
                 provider.is_available = True
                 provider.error_count = 0
             else:
@@ -226,7 +229,8 @@ class ProviderTracker:
     def get_best_available_provider(self) -> Optional[str]:
         """Get the best available provider"""
         available_providers = [
-            (name, config) for name, config in self.providers.items()
+            (name, config)
+            for name, config in self.providers.items()
             if self.is_provider_available(name)
         ]
 
@@ -248,10 +252,12 @@ class DockerCodeExecutor:
 
     def __init__(self, config: Dict[str, Any]):
         self.config = config
-        self.work_dir = config.get("work_dir", '/opt/ambivo/work_dir')
+        self.work_dir = config.get("work_dir", "/opt/ambivo/work_dir")
         self.docker_images = config.get("docker_images", ["sgosain/amb-ubuntu-python-public-pod"])
         self.timeout = config.get("timeout", 60)
-        self.default_image = self.docker_images[0] if self.docker_images else "sgosain/amb-ubuntu-python-public-pod"
+        self.default_image = (
+            self.docker_images[0] if self.docker_images else "sgosain/amb-ubuntu-python-public-pod"
+        )
 
         if DOCKER_AVAILABLE:
             try:
@@ -263,14 +269,12 @@ class DockerCodeExecutor:
         else:
             self.available = False
 
-    def execute_code(self, code: str, language: str = "python", files: Dict[str, str] = None) -> Dict[str, Any]:
+    def execute_code(
+        self, code: str, language: str = "python", files: Dict[str, str] = None
+    ) -> Dict[str, Any]:
         """Execute code in Docker container"""
         if not self.available:
-            return {
-                'success': False,
-                'error': 'Docker not available',
-                'language': language
-            }
+            return {"success": False, "error": "Docker not available", "language": language}
 
         try:
             with tempfile.TemporaryDirectory() as temp_dir:
@@ -293,57 +297,57 @@ class DockerCodeExecutor:
                         file_path.write_text(content)
 
                 container_config = {
-                    'image': self.default_image,
-                    'command': cmd,
-                    'volumes': {str(temp_path): {'bind': '/workspace', 'mode': 'rw'}},
-                    'working_dir': '/workspace',
-                    'mem_limit': '512m',
-                    'network_disabled': True,
-                    'remove': True,
-                    'stdout': True,
-                    'stderr': True
+                    "image": self.default_image,
+                    "command": cmd,
+                    "volumes": {str(temp_path): {"bind": "/workspace", "mode": "rw"}},
+                    "working_dir": "/workspace",
+                    "mem_limit": "512m",
+                    "network_disabled": True,
+                    "remove": True,
+                    "stdout": True,
+                    "stderr": True,
                 }
 
                 start_time = time.time()
                 container = self.docker_client.containers.run(**container_config)
                 execution_time = time.time() - start_time
 
-                output = container.decode('utf-8') if isinstance(container, bytes) else str(container)
+                output = (
+                    container.decode("utf-8") if isinstance(container, bytes) else str(container)
+                )
 
                 return {
-                    'success': True,
-                    'output': output,
-                    'execution_time': execution_time,
-                    'language': language
+                    "success": True,
+                    "output": output,
+                    "execution_time": execution_time,
+                    "language": language,
                 }
 
         except docker.errors.ContainerError as e:
             return {
-                'success': False,
-                'error': f"Container error: {e.stderr.decode('utf-8') if e.stderr else 'Unknown error'}",
-                'exit_code': e.exit_status,
-                'language': language
+                "success": False,
+                "error": f"Container error: {e.stderr.decode('utf-8') if e.stderr else 'Unknown error'}",
+                "exit_code": e.exit_status,
+                "language": language,
             }
         except Exception as e:
-            return {
-                'success': False,
-                'error': str(e),
-                'language': language
-            }
+            return {"success": False, "error": str(e), "language": language}
 
 
 class StreamSubType(Enum):
     """Types of streaming content to distinguish between actual results vs interim status"""
-    CONTENT = "content"        # Actual response content
-    STATUS = "status"          # Status updates, thinking, interim info
-    RESULT = "result"          # Search results, data outputs
-    ERROR = "error"            # Error messages
-    METADATA = "metadata"      # Additional metadata or context
+
+    CONTENT = "content"  # Actual response content
+    STATUS = "status"  # Status updates, thinking, interim info
+    RESULT = "result"  # Search results, data outputs
+    ERROR = "error"  # Error messages
+    METADATA = "metadata"  # Additional metadata or context
 
 
 @dataclass
 class StreamChunk:
     """Structured streaming chunk with sub-type information"""
+
     text: str
     sub_type: StreamSubType = StreamSubType.CONTENT
     metadata: Dict[str, Any] = field(default_factory=dict)
@@ -356,7 +360,7 @@ class StreamChunk:
             "text": self.text,
             "sub_type": self.sub_type.value,
             "metadata": self.metadata,
-            "timestamp": self.timestamp.isoformat()
+            "timestamp": self.timestamp.isoformat(),
         }
 
 
@@ -366,22 +370,24 @@ class BaseAgent(ABC):
     Every agent automatically gets a context with session_id, user_id, etc.
     """
 
-    def __init__(self,
-                 agent_id: str = None,
-                 role: AgentRole = AgentRole.ASSISTANT,
-                 user_id: str = None,
-                 tenant_id: str = "default",
-                 session_metadata: Dict[str, Any] = None,
-                 memory_manager=None,
-                 llm_service=None,
-                 config: Dict[str, Any] = None,
-                 name: str = None,
-                 description: str = None,
-                 auto_configure: bool = True,
-                 session_id: str = None,
-                 conversation_id: str = None,
-                 system_message: str = None,
-                 **kwargs):
+    def __init__(
+        self,
+        agent_id: str = None,
+        role: AgentRole = AgentRole.ASSISTANT,
+        user_id: str = None,
+        tenant_id: str = "default",
+        session_metadata: Dict[str, Any] = None,
+        memory_manager=None,
+        llm_service=None,
+        config: Dict[str, Any] = None,
+        name: str = None,
+        description: str = None,
+        auto_configure: bool = True,
+        session_id: str = None,
+        conversation_id: str = None,
+        system_message: str = None,
+        **kwargs,
+    ):
 
         # Auto-generate agent_id if not provided
         if agent_id is None:
@@ -397,6 +403,7 @@ class BaseAgent(ABC):
         if config is None and auto_configure:
             try:
                 from ..config.loader import load_config
+
                 config = load_config()
             except Exception as e:
                 logging.warning(f"Could not load config for auto-configuration: {e}")
@@ -404,20 +411,19 @@ class BaseAgent(ABC):
 
         self.config = config or {}
 
-        self.context = self._create_agent_context(user_id, tenant_id,
-                                                  session_metadata,
-                                                  session_id,
-                                                  conversation_id)
+        self.context = self._create_agent_context(
+            user_id, tenant_id, session_metadata, session_id, conversation_id
+        )
 
         # Auto-configure memory if not provided and auto-configure is enabled
         if memory_manager is None and auto_configure:
             try:
                 from ..core.memory import create_redis_memory_manager
+
                 self.memory = create_redis_memory_manager(
-                    agent_id=agent_id,
-                    redis_config=None  # Will load from config automatically
+                    agent_id=agent_id, redis_config=None  # Will load from config automatically
                 )
-                #logging.info(f"Auto-configured memory for agent {agent_id}")
+                # logging.info(f"Auto-configured memory for agent {agent_id}")
             except Exception as e:
                 logging.error(f"Failed to auto-configure memory for {agent_id}: {e}")
                 self.memory = None
@@ -428,6 +434,7 @@ class BaseAgent(ABC):
         if llm_service is None and auto_configure:
             try:
                 from ..core.llm import create_multi_provider_llm_service
+
                 self.llm_service = create_multi_provider_llm_service()
                 logging.info(f"Auto-configured LLM service for agent {agent_id}")
             except Exception as e:
@@ -436,7 +443,7 @@ class BaseAgent(ABC):
         else:
             self.llm_service = llm_service
 
-        self.tools = kwargs.get('tools', [])
+        self.tools = kwargs.get("tools", [])
         self.active = True
 
         # Initialize executor
@@ -448,18 +455,15 @@ class BaseAgent(ABC):
             AgentRole.ASSISTANT: """You are a helpful AI assistant. Provide accurate, thoughtful responses to user queries. 
             Maintain conversation context and reference previous discussions when relevant. 
             Be concise but thorough in explanations.""",
-
             AgentRole.CODE_EXECUTOR: """You are a code execution specialist. Write clean, well-commented code. 
             Always explain what the code does before execution. Handle errors gracefully and suggest fixes. 
             Use best practices for security and efficiency.""",
-
             AgentRole.RESEARCHER: """You are a research specialist. Provide thorough, well-sourced information. 
             Verify facts when possible and clearly distinguish between verified information and analysis. 
             Structure your research logically.""",
-
             AgentRole.COORDINATOR: """You are an intelligent coordinator. Analyze user requests carefully and 
             route them to the most appropriate specialized agent. Consider context, complexity, and agent 
-            capabilities when making routing decisions."""
+            capabilities when making routing decisions.""",
         }
         return role_messages.get(self.role, "You are a helpful AI agent.")
 
@@ -469,28 +473,33 @@ class BaseAgent(ABC):
 
         # Add context-specific instructions
         if context:
-            conversation_history = context.get('conversation_history', [])
+            conversation_history = context.get("conversation_history", [])
             if conversation_history:
                 base_message += "\n\nIMPORTANT: This conversation has history. Consider previous messages when responding and maintain conversational continuity."
 
             # Add agent-specific context
-            if self.role == AgentRole.CODE_EXECUTOR and context.get('streaming'):
-                base_message += "\n\nYou are in streaming mode. Provide step-by-step progress updates."
+            if self.role == AgentRole.CODE_EXECUTOR and context.get("streaming"):
+                base_message += (
+                    "\n\nYou are in streaming mode. Provide step-by-step progress updates."
+                )
 
             elif self.role == AgentRole.COORDINATOR:
-                available_agents = context.get('available_agents', [])
+                available_agents = context.get("available_agents", [])
                 if available_agents:
-                    base_message += f"\n\nAvailable specialized agents: {', '.join(available_agents)}"
+                    base_message += (
+                        f"\n\nAvailable specialized agents: {', '.join(available_agents)}"
+                    )
 
         return base_message
 
-    def _create_agent_context(self,
-                              user_id: str = None,
-                              tenant_id: str = "default",
-                              session_metadata: Dict[str, Any] = None,
-                              session_id: str = None,
-                              conversation_id: str = None
-                              ) -> AgentContext:
+    def _create_agent_context(
+        self,
+        user_id: str = None,
+        tenant_id: str = "default",
+        session_metadata: Dict[str, Any] = None,
+        session_id: str = None,
+        conversation_id: str = None,
+    ) -> AgentContext:
         """Create auto-context for this agent instance"""
 
         # Auto-generate user_id if not provided
@@ -510,18 +519,20 @@ class BaseAgent(ABC):
             user_id=user_id,
             tenant_id=tenant_id,
             agent_id=self.agent_id,
-            metadata=session_metadata or {}
+            metadata=session_metadata or {},
         )
 
     @classmethod
-    def create(cls,
-               agent_id: str = None,
-               user_id: str = None,
-               tenant_id: str = "default",
-               session_metadata: Dict[str, Any] = None,
-               session_id: str = None,
-               conversation_id: str = None,
-               **kwargs) -> Tuple['BaseAgent', AgentContext]:
+    def create(
+        cls,
+        agent_id: str = None,
+        user_id: str = None,
+        tenant_id: str = "default",
+        session_metadata: Dict[str, Any] = None,
+        session_id: str = None,
+        conversation_id: str = None,
+        **kwargs,
+    ) -> Tuple["BaseAgent", AgentContext]:
         """
         🌟 DEFAULT: Create agent and return both agent and context
         This is the RECOMMENDED way to create agents with auto-context
@@ -542,18 +553,20 @@ class BaseAgent(ABC):
             session_id=session_id,
             conversation_id=conversation_id,
             auto_configure=True,
-            **kwargs
+            **kwargs,
         )
 
         return agent, agent.context
 
     @classmethod
-    def create_simple(cls,
-                      agent_id: str = None,
-                      user_id: str = None,
-                      tenant_id: str = "default",
-                      session_metadata: Dict[str, Any] = None,
-                      **kwargs) -> 'BaseAgent':
+    def create_simple(
+        cls,
+        agent_id: str = None,
+        user_id: str = None,
+        tenant_id: str = "default",
+        session_metadata: Dict[str, Any] = None,
+        **kwargs,
+    ) -> "BaseAgent":
         """
         Create agent with auto-context (returns agent only)
 
@@ -572,18 +585,20 @@ class BaseAgent(ABC):
             tenant_id=tenant_id,
             session_metadata=session_metadata,
             auto_configure=True,
-            **kwargs
+            **kwargs,
         )
 
     @classmethod
-    def create_advanced(cls,
-                        agent_id: str,
-                        memory_manager,
-                        llm_service=None,
-                        config: Dict[str, Any] = None,
-                        user_id: str = None,
-                        tenant_id: str = "default",
-                        **kwargs):
+    def create_advanced(
+        cls,
+        agent_id: str,
+        memory_manager,
+        llm_service=None,
+        config: Dict[str, Any] = None,
+        user_id: str = None,
+        tenant_id: str = "default",
+        **kwargs,
+    ):
         """
         Advanced factory method for explicit dependency injection
 
@@ -600,15 +615,11 @@ class BaseAgent(ABC):
             user_id=user_id,
             tenant_id=tenant_id,
             auto_configure=False,  # Disable auto-config when using advanced mode
-            **kwargs
+            **kwargs,
         )
 
-
-
     async def chat(self, message: str, **kwargs) -> str:
-        """
-
-        """
+        """ """
         try:
 
             user_message = AgentMessage(
@@ -619,7 +630,7 @@ class BaseAgent(ABC):
                 message_type=MessageType.USER_INPUT,
                 session_id=self.context.session_id,
                 conversation_id=self.context.conversation_id,
-                metadata={'chat_interface': True, 'simplified_call': True, **kwargs}
+                metadata={"chat_interface": True, "simplified_call": True, **kwargs},
             )
 
             execution_context = self.context.to_execution_context()
@@ -701,11 +712,7 @@ class BaseAgent(ABC):
                 message_type=MessageType.USER_INPUT,
                 session_id=self.context.session_id,
                 conversation_id=self.context.conversation_id,
-                metadata={
-                    'chat_interface': True,
-                    'streaming_call': True,
-                    **kwargs
-                }
+                metadata={"chat_interface": True, "streaming_call": True, **kwargs},
             )
 
             # Get execution context from auto-context
@@ -722,12 +729,13 @@ class BaseAgent(ABC):
             yield StreamChunk(
                 text=error_msg,
                 sub_type=StreamSubType.ERROR,
-                metadata={'error': True, 'agent_id': self.agent_id}
+                metadata={"error": True, "agent_id": self.agent_id},
             )
 
     @abstractmethod
-    async def process_message_stream(self, message: AgentMessage, context: ExecutionContext = None) -> AsyncIterator[
-        StreamChunk]:
+    async def process_message_stream(
+        self, message: AgentMessage, context: ExecutionContext = None
+    ) -> AsyncIterator[StreamChunk]:
         """
         🌟 NEW: Stream processing method - must be implemented by subclasses
 
@@ -756,11 +764,9 @@ class BaseAgent(ABC):
         """Update context metadata"""
         self.context.update_metadata(**kwargs)
 
-
-
-    async def get_conversation_history(self,
-                                       limit: int = None,
-                                       include_metadata: bool = True) -> List[Dict[str, Any]]:
+    async def get_conversation_history(
+        self, limit: int = None, include_metadata: bool = True
+    ) -> List[Dict[str, Any]]:
         """
         Get conversation history for this agent's session
 
@@ -778,8 +784,7 @@ class BaseAgent(ABC):
 
             # Get history using session_id from auto-context
             history = self.memory.get_recent_messages(
-                limit=limit or 10,
-                conversation_id=self.context.conversation_id
+                limit=limit or 10, conversation_id=self.context.conversation_id
             )
 
             # Add context information to each message
@@ -788,10 +793,10 @@ class BaseAgent(ABC):
                 if include_metadata:
                     msg_with_context = {
                         **msg,
-                        'session_id': self.context.session_id,
-                        'user_id': self.context.user_id,
-                        'agent_id': self.agent_id,
-                        'conversation_id': self.context.conversation_id
+                        "session_id": self.context.session_id,
+                        "user_id": self.context.user_id,
+                        "agent_id": self.agent_id,
+                        "conversation_id": self.context.conversation_id,
                     }
                 else:
                     msg_with_context = msg
@@ -804,10 +809,9 @@ class BaseAgent(ABC):
             logging.error(f"Failed to get conversation history for {self.agent_id}: {e}")
             return []
 
-    async def add_to_conversation_history(self,
-                                          message: str,
-                                          message_type: str = "user",
-                                          metadata: Dict[str, Any] = None) -> bool:
+    async def add_to_conversation_history(
+        self, message: str, message_type: str = "user", metadata: Dict[str, Any] = None
+    ) -> bool:
         """
         Add a message to conversation history
 
@@ -830,15 +834,19 @@ class BaseAgent(ABC):
                 sender_id=self.agent_id if message_type == "agent" else f"{message_type}_sender",
                 recipient_id=None,
                 content=message,
-                message_type=MessageType.AGENT_RESPONSE if message_type == "agent" else MessageType.USER_INPUT,
+                message_type=(
+                    MessageType.AGENT_RESPONSE
+                    if message_type == "agent"
+                    else MessageType.USER_INPUT
+                ),
                 session_id=self.context.session_id,
                 conversation_id=self.context.conversation_id,
                 metadata={
-                    'type': message_type,
-                    'user_id': self.context.user_id,
-                    'agent_id': self.agent_id,
-                    **(metadata or {})
-                }
+                    "type": message_type,
+                    "user_id": self.context.user_id,
+                    "agent_id": self.agent_id,
+                    **(metadata or {}),
+                },
             )
 
             # Store in memory
@@ -881,19 +889,21 @@ class BaseAgent(ABC):
 
             if not history:
                 return {
-                    'total_messages': 0,
-                    'user_messages': 0,
-                    'agent_messages': 0,
-                    'session_duration': '0 minutes',
-                    'first_message': None,
-                    'last_message': None,
-                    'session_id': self.context.session_id
+                    "total_messages": 0,
+                    "user_messages": 0,
+                    "agent_messages": 0,
+                    "session_duration": "0 minutes",
+                    "first_message": None,
+                    "last_message": None,
+                    "session_id": self.context.session_id,
                 }
 
             # Analyze conversation
             total_messages = len(history)
-            user_messages = len([msg for msg in history if msg.get('message_type') == 'user_input'])
-            agent_messages = len([msg for msg in history if msg.get('message_type') == 'agent_response'])
+            user_messages = len([msg for msg in history if msg.get("message_type") == "user_input"])
+            agent_messages = len(
+                [msg for msg in history if msg.get("message_type") == "agent_response"]
+            )
 
             # Calculate session duration
             first_msg_time = self.context.created_at
@@ -902,25 +912,28 @@ class BaseAgent(ABC):
             duration_minutes = int(duration.total_seconds() / 60)
 
             return {
-                'total_messages': total_messages,
-                'user_messages': user_messages,
-                'agent_messages': agent_messages,
-                'session_duration': f"{duration_minutes} minutes",
-                'first_message': history[0].get('content', '')[:100] + "..." if len(
-                    history[0].get('content', '')) > 100 else history[0].get('content', '') if history else None,
-                'last_message': history[-1].get('content', '')[:100] + "..." if len(
-                    history[-1].get('content', '')) > 100 else history[-1].get('content', '') if history else None,
-                'session_id': self.context.session_id,
-                'conversation_id': self.context.conversation_id,
-                'user_id': self.context.user_id
+                "total_messages": total_messages,
+                "user_messages": user_messages,
+                "agent_messages": agent_messages,
+                "session_duration": f"{duration_minutes} minutes",
+                "first_message": (
+                    history[0].get("content", "")[:100] + "..."
+                    if len(history[0].get("content", "")) > 100
+                    else history[0].get("content", "") if history else None
+                ),
+                "last_message": (
+                    history[-1].get("content", "")[:100] + "..."
+                    if len(history[-1].get("content", "")) > 100
+                    else history[-1].get("content", "") if history else None
+                ),
+                "session_id": self.context.session_id,
+                "conversation_id": self.context.conversation_id,
+                "user_id": self.context.user_id,
             }
 
         except Exception as e:
             logging.error(f"Failed to get conversation summary for {self.agent_id}: {e}")
-            return {
-                'error': str(e),
-                'session_id': self.context.session_id
-            }
+            return {"error": str(e), "session_id": self.context.session_id}
 
     async def _with_auto_context(self, operation_name: str, **kwargs) -> Dict[str, Any]:
         """
@@ -931,21 +944,18 @@ class BaseAgent(ABC):
 
         # Add context info to operation metadata
         operation_metadata = {
-            'session_id': self.context.session_id,
-            'user_id': self.context.user_id,
-            'tenant_id': self.context.tenant_id,
-            'operation': operation_name,
-            'timestamp': datetime.now().isoformat(),
-            **kwargs
+            "session_id": self.context.session_id,
+            "user_id": self.context.user_id,
+            "tenant_id": self.context.tenant_id,
+            "operation": operation_name,
+            "timestamp": datetime.now().isoformat(),
+            **kwargs,
         }
 
         # Update context metadata
         self.context.update_metadata(**operation_metadata)
 
-        return {
-            'execution_context': execution_context,
-            'operation_metadata': operation_metadata
-        }
+        return {"execution_context": execution_context, "operation_metadata": operation_metadata}
 
     # 🧹 SESSION CLEANUP
 
@@ -955,7 +965,7 @@ class BaseAgent(ABC):
             session_id = self.context.session_id
 
             # Clear memory for this session
-            if hasattr(self, 'memory') and self.memory:
+            if hasattr(self, "memory") and self.memory:
                 try:
                     # Commented out temporarily as noted in original
                     # self.memory.clear_memory(self.context.conversation_id)
@@ -964,7 +974,7 @@ class BaseAgent(ABC):
                     logging.warning(f"⚠️  Could not clear memory: {e}")
 
             # Shutdown executor
-            if hasattr(self, 'executor') and self.executor:
+            if hasattr(self, "executor") and self.executor:
                 try:
                     self.executor.shutdown(wait=True)
                     logging.info(f"🛑 Shutdown executor for session {session_id}")
@@ -995,9 +1005,9 @@ class BaseAgent(ABC):
             raise ValueError(f"Tool {tool_name} not found")
 
         # Apply auto-context to tool execution
-        context_data = await self._with_auto_context("tool_execution",
-                                                     tool_name=tool_name,
-                                                     parameters=parameters)
+        context_data = await self._with_auto_context(
+            "tool_execution", tool_name=tool_name, parameters=parameters
+        )
 
         try:
             if asyncio.iscoroutinefunction(tool.function):
@@ -1008,25 +1018,23 @@ class BaseAgent(ABC):
                 )
 
             return {
-                'success': True,
-                'result': result,
-                'session_id': self.context.session_id,
-                'context': context_data
+                "success": True,
+                "result": result,
+                "session_id": self.context.session_id,
+                "context": context_data,
             }
         except Exception as e:
-            return {
-                'success': False,
-                'error': str(e),
-                'session_id': self.context.session_id
-            }
+            return {"success": False, "error": str(e), "session_id": self.context.session_id}
 
-    def create_response(self,
-                        content: str,
-                        recipient_id: str,
-                        message_type: MessageType = MessageType.AGENT_RESPONSE,
-                        metadata: Dict[str, Any] = None,
-                        session_id: str = None,
-                        conversation_id: str = None) -> AgentMessage:
+    def create_response(
+        self,
+        content: str,
+        recipient_id: str,
+        message_type: MessageType = MessageType.AGENT_RESPONSE,
+        metadata: Dict[str, Any] = None,
+        session_id: str = None,
+        conversation_id: str = None,
+    ) -> AgentMessage:
         """
         Create a response message with auto-context
         Uses agent's context if session_id/conversation_id not provided
@@ -1039,13 +1047,15 @@ class BaseAgent(ABC):
             message_type=message_type,
             metadata=metadata or {},
             session_id=session_id or self.context.session_id,  # 🎯 Auto-context!
-            conversation_id=conversation_id or self.context.conversation_id  # 🎯 Auto-context!
+            conversation_id=conversation_id or self.context.conversation_id,  # 🎯 Auto-context!
         )
 
     # 📨 ABSTRACT METHOD (must be implemented by subclasses)
 
     @abstractmethod
-    async def process_message(self, message: AgentMessage, context: ExecutionContext = None) -> AgentMessage:
+    async def process_message(
+        self, message: AgentMessage, context: ExecutionContext = None
+    ) -> AgentMessage:
         """
         Process incoming message and return response
         Uses agent's auto-context if context not provided
@@ -1056,13 +1066,14 @@ class BaseAgent(ABC):
         # Subclasses must implement this
         pass
 
-    def register_agent(self, agent: 'BaseAgent'):
+    def register_agent(self, agent: "BaseAgent"):
         """Default implementation - only ProxyAgent should override this"""
         return False
 
 
 # 🎯 CONTEXT MANAGER FOR AUTO-CONTEXT AGENTS
 
+
 class AgentSession:
     """
     Context manager for BaseAgent instances with automatic cleanup
@@ -1074,12 +1085,14 @@ class AgentSession:
         # Agent automatically cleaned up
     """
 
-    def __init__(self,
-                 agent_class,
-                 user_id: str = None,
-                 tenant_id: str = "default",
-                 session_metadata: Dict[str, Any] = None,
-                 **agent_kwargs):
+    def __init__(
+        self,
+        agent_class,
+        user_id: str = None,
+        tenant_id: str = "default",
+        session_metadata: Dict[str, Any] = None,
+        **agent_kwargs,
+    ):
         self.agent_class = agent_class
         self.user_id = user_id
         self.tenant_id = tenant_id
@@ -1093,7 +1106,7 @@ class AgentSession:
             user_id=self.user_id,
             tenant_id=self.tenant_id,
             session_metadata=self.session_metadata,
-            **self.agent_kwargs
+            **self.agent_kwargs,
         )
         return self.agent
 
@@ -1105,6 +1118,7 @@ class AgentSession:
 
 # 🚀 CONVENIENCE FUNCTIONS FOR QUICK AGENT USAGE
 
+
 async def quick_chat(agent_class, message: str, user_id: str = None, **kwargs) -> str:
     """
     🌟 ULTRA-SIMPLIFIED: One-liner agent chat
@@ -1141,7 +1155,9 @@ def quick_chat_sync(agent_class, message: str, user_id: str = None, **kwargs) ->
                 new_loop = asyncio.new_event_loop()
                 asyncio.set_event_loop(new_loop)
                 try:
-                    return new_loop.run_until_complete(quick_chat(agent_class, message, user_id, **kwargs))
+                    return new_loop.run_until_complete(
+                        quick_chat(agent_class, message, user_id, **kwargs)
+                    )
                 finally:
                     new_loop.close()
 
@@ -1154,4 +1170,4 @@ def quick_chat_sync(agent_class, message: str, user_id: str = None, **kwargs) ->
             return asyncio.run(quick_chat(agent_class, message, user_id, **kwargs))
 
     except Exception as e:
-        return f"Quick sync chat error: {str(e)}"
\ No newline at end of file
+        return f"Quick sync chat error: {str(e)}"
