@@ -3,16 +3,16 @@
 LLM service with multiple provider support and automatic rotation.
 """
 
-import os
 import asyncio
 import logging
+import os
 import re
 from abc import ABC, abstractmethod
 from datetime import datetime, timedelta
-from typing import Dict, List, Any, Optional, AsyncIterator
+from typing import Any, AsyncIterator, Dict, List, Optional
 
+from ..config.loader import get_config_section, load_config
 from .base import ProviderConfig, ProviderTracker
-from ..config.loader import load_config, get_config_section
 
 # LLM Provider imports
 try:
@@ -23,8 +23,8 @@ try:
     from langchain_aws import BedrockEmbeddings, BedrockLLM
     from langchain_openai import ChatOpenAI, OpenAIEmbeddings
     from langchain_voyageai import VoyageAIEmbeddings
-    from llama_index.embeddings.langchain import LangchainEmbedding
     from llama_index.core.node_parser import SentenceSplitter
+    from llama_index.embeddings.langchain import LangchainEmbedding
 
     LANGCHAIN_AVAILABLE = True
 except ImportError as e:
@@ -41,13 +41,16 @@ class LLMServiceInterface(ABC):
         pass
 
     @abstractmethod
-    async def query_knowledge_base(self, query: str, kb_name: str, context: Dict[str, Any] = None) -> tuple[
-        str, List[Dict]]:
+    async def query_knowledge_base(
+        self, query: str, kb_name: str, context: Dict[str, Any] = None
+    ) -> tuple[str, List[Dict]]:
         """Query a knowledge base"""
         pass
 
     @abstractmethod
-    async def generate_response_stream(self, prompt: str, context: Dict[str, Any] = None) -> AsyncIterator[str]:
+    async def generate_response_stream(
+        self, prompt: str, context: Dict[str, Any] = None
+    ) -> AsyncIterator[str]:
         """Generate a streaming response using the LLM"""
         pass
 
@@ -59,17 +62,17 @@ def _clean_chunk_content(chunk: str) -> str:
 
     # Remove common unwanted patterns
     unwanted_patterns = [
-        r'<bound method.*?>',
-        r'AIMessageChunk\(.*?\)',
-        r'content=\'\'',
-        r'additional_kwargs=\{\}',
-        r'response_metadata=.*?',
-        r'id=\'run--.*?\''
+        r"<bound method.*?>",
+        r"AIMessageChunk\(.*?\)",
+        r"content=\'\'",
+        r"additional_kwargs=\{\}",
+        r"response_metadata=.*?",
+        r"id=\'run--.*?\'",
     ]
 
     cleaned = chunk
     for pattern in unwanted_patterns:
-        cleaned = re.sub(pattern, '', cleaned)
+        cleaned = re.sub(pattern, "", cleaned)
 
     # Only strip if the entire chunk is whitespace, preserve internal formatting
     return cleaned if cleaned.strip() else ""
@@ -82,14 +85,14 @@ class MultiProviderLLMService(LLMServiceInterface):
         # Load configuration from YAML if not provided
         if config_data is None:
             config = load_config()
-            config_data = get_config_section('llm', config)
+            config_data = get_config_section("llm", config)
 
         self.config_data = config_data
         self.preferred_provider = preferred_provider
         self.provider_tracker = ProviderTracker()
         self.current_llm = None
         self.current_embeddings = None
-        self.temperature = config_data.get('temperature', 0.5)
+        self.temperature = config_data.get("temperature", 0.5)
 
         if not LANGCHAIN_AVAILABLE:
             raise ImportError("LangChain dependencies are required but not available")
@@ -121,7 +124,7 @@ class MultiProviderLLMService(LLMServiceInterface):
                 priority=1,
                 max_requests_per_minute=50,
                 max_requests_per_hour=1000,
-                cooldown_minutes=5
+                cooldown_minutes=5,
             )
 
         # OpenAI configuration
@@ -132,7 +135,7 @@ class MultiProviderLLMService(LLMServiceInterface):
                 priority=2,
                 max_requests_per_minute=60,
                 max_requests_per_hour=3600,
-                cooldown_minutes=3
+                cooldown_minutes=3,
             )
 
         # Bedrock configuration
@@ -143,7 +146,7 @@ class MultiProviderLLMService(LLMServiceInterface):
                 priority=3,
                 max_requests_per_minute=40,
                 max_requests_per_hour=2400,
-                cooldown_minutes=10
+                cooldown_minutes=10,
             )
 
         if not self.provider_tracker.providers:
@@ -172,6 +175,7 @@ class MultiProviderLLMService(LLMServiceInterface):
                     # Configure LlamaIndex Settings
                     try:
                         from llama_index.core import Settings
+
                         Settings.llm = self.current_llm
                         Settings.embed_model = self.embed_model
                         Settings.chunk_size = 512
@@ -186,15 +190,15 @@ class MultiProviderLLMService(LLMServiceInterface):
 
     def _setup_anthropic(self):
         """Setup Anthropic provider"""
-        os.environ['ANTHROPIC_API_KEY'] = self.config_data["anthropic_api_key"]
+        os.environ["ANTHROPIC_API_KEY"] = self.config_data["anthropic_api_key"]
         if self.config_data.get("voyage_api_key"):
-            os.environ['VOYAGE_API_KEY'] = self.config_data["voyage_api_key"]
+            os.environ["VOYAGE_API_KEY"] = self.config_data["voyage_api_key"]
 
         self.current_llm = ChatAnthropic(
             model_name="claude-3-5-sonnet-20241022",
             temperature=self.temperature,
             timeout=None,
-            stop=None
+            stop=None,
         )
 
         if self.config_data.get("voyage_api_key"):
@@ -202,7 +206,7 @@ class MultiProviderLLMService(LLMServiceInterface):
 
     def _setup_openai(self):
         """Setup OpenAI provider"""
-        os.environ['OPENAI_API_KEY'] = self.config_data["openai_api_key"]
+        os.environ["OPENAI_API_KEY"] = self.config_data["openai_api_key"]
         openai.api_key = self.config_data["openai_api_key"]
 
         self.current_llm = ChatOpenAI(model="gpt-4o", temperature=self.temperature)
@@ -211,16 +215,15 @@ class MultiProviderLLMService(LLMServiceInterface):
     def _setup_bedrock(self):
         """Setup Bedrock provider"""
         boto3_client = boto3.client(
-            'bedrock-runtime',
-            region_name=self.config_data.get('aws_region', 'us-east-1'),
-            aws_access_key_id=self.config_data['aws_access_key_id'],
-            aws_secret_access_key=self.config_data['aws_secret_access_key']
+            "bedrock-runtime",
+            region_name=self.config_data.get("aws_region", "us-east-1"),
+            aws_access_key_id=self.config_data["aws_access_key_id"],
+            aws_secret_access_key=self.config_data["aws_secret_access_key"],
         )
 
         self.current_llm = BedrockLLM(model="cohere.command-text-v14", client=boto3_client)
         self.current_embeddings = BedrockEmbeddings(
-            model_id="amazon.titan-embed-text-v1",
-            client=boto3_client
+            model_id="amazon.titan-embed-text-v1", client=boto3_client
         )
 
     # ambivo_agents/core/llm.py - FIXED LLM rotation logic
@@ -236,16 +239,17 @@ class MultiProviderLLMService(LLMServiceInterface):
         # Find available providers (excluding current one)
         fallback_providers = []
         for name, config in self.provider_tracker.providers.items():
-            if (name != self.current_provider and
-                    self.provider_tracker.is_provider_available(name)):
+            if name != self.current_provider and self.provider_tracker.is_provider_available(name):
                 fallback_providers.append((name, config))
 
         if not fallback_providers:
             # Check if any providers are in cooldown and can be restored
             for name, config in self.provider_tracker.providers.items():
-                if (name != self.current_provider and
-                        not config.is_available and
-                        config.last_error_time):
+                if (
+                    name != self.current_provider
+                    and not config.is_available
+                    and config.last_error_time
+                ):
 
                     time_since_error = datetime.now() - config.last_error_time
                     if time_since_error > timedelta(minutes=config.cooldown_minutes):
@@ -293,14 +297,18 @@ class MultiProviderLLMService(LLMServiceInterface):
 
                 # Check if we should retry with different provider
                 should_retry = (
-                        any(keyword in error_str for keyword in ['429', 'rate limit', 'quota', 'insufficient_quota']) or
-                        any(keyword in error_str for keyword in ['timeout', 'connection', 'network']) or
-                        retry_count < max_retries - 1
+                    any(
+                        keyword in error_str
+                        for keyword in ["429", "rate limit", "quota", "insufficient_quota"]
+                    )
+                    or any(keyword in error_str for keyword in ["timeout", "connection", "network"])
+                    or retry_count < max_retries - 1
                 )
 
                 if should_retry:
                     logging.warning(
-                        f"Attempting fallback from {self.current_provider} (attempt {retry_count + 1}/{max_retries})")
+                        f"Attempting fallback from {self.current_provider} (attempt {retry_count + 1}/{max_retries})"
+                    )
 
                     if self._try_fallback_provider():
                         retry_count += 1
@@ -334,14 +342,18 @@ class MultiProviderLLMService(LLMServiceInterface):
 
                 # Check if we should retry
                 should_retry = (
-                        any(keyword in error_str for keyword in ['429', 'rate limit', 'quota', 'insufficient_quota']) or
-                        any(keyword in error_str for keyword in ['timeout', 'connection', 'network']) or
-                        retry_count < max_retries - 1
+                    any(
+                        keyword in error_str
+                        for keyword in ["429", "rate limit", "quota", "insufficient_quota"]
+                    )
+                    or any(keyword in error_str for keyword in ["timeout", "connection", "network"])
+                    or retry_count < max_retries - 1
                 )
 
                 if should_retry:
                     logging.warning(
-                        f"Attempting fallback from {self.current_provider} (attempt {retry_count + 1}/{max_retries})")
+                        f"Attempting fallback from {self.current_provider} (attempt {retry_count + 1}/{max_retries})"
+                    )
 
                     if self._try_fallback_provider():
                         retry_count += 1
@@ -355,7 +367,9 @@ class MultiProviderLLMService(LLMServiceInterface):
 
         raise RuntimeError(f"All {max_retries} providers exhausted")
 
-    async def generate_response(self, prompt: str, context: Dict[str, Any] = None, system_message: str = None) -> str:
+    async def generate_response(
+        self, prompt: str, context: Dict[str, Any] = None, system_message: str = None
+    ) -> str:
         """Generate a response using the current LLM provider Preserves context across provider switches"""
         if not self.current_llm:
             raise RuntimeError("No LLM provider available")
@@ -365,24 +379,24 @@ class MultiProviderLLMService(LLMServiceInterface):
 
         def _generate():
             try:
-                if hasattr(self.current_llm, 'invoke'):
+                if hasattr(self.current_llm, "invoke"):
                     # 🔥 FIX: Use context-enhanced prompt
                     response = self.current_llm.invoke(final_prompt)
-                    if hasattr(response, 'content'):
+                    if hasattr(response, "content"):
                         return response.content
-                    elif hasattr(response, 'text'):
+                    elif hasattr(response, "text"):
                         return response.text
                     else:
                         return str(response)
-                elif hasattr(self.current_llm, 'predict'):
+                elif hasattr(self.current_llm, "predict"):
                     # 🔥 FIX: Use context-enhanced prompt
                     return self.current_llm.predict(final_prompt)
-                elif hasattr(self.current_llm, '__call__'):
+                elif hasattr(self.current_llm, "__call__"):
                     # 🔥 FIX: Use context-enhanced prompt
                     response = self.current_llm(final_prompt)
-                    if hasattr(response, 'content'):
+                    if hasattr(response, "content"):
                         return response.content
-                    elif hasattr(response, 'text'):
+                    elif hasattr(response, "text"):
                         return response.text
                     else:
                         return str(response)
@@ -398,10 +412,9 @@ class MultiProviderLLMService(LLMServiceInterface):
         except Exception as e:
             raise RuntimeError(f"Failed to generate response after retries: {str(e)}")
 
-    def _build_system_aware_prompt(self,
-                                   user_prompt: str,
-                                   context: Dict[str, Any] = None,
-                                   system_message: str = None) -> str:
+    def _build_system_aware_prompt(
+        self, user_prompt: str, context: Dict[str, Any] = None, system_message: str = None
+    ) -> str:
         """🆕 Build prompt with system message integration"""
 
         prompt_parts = []
@@ -411,17 +424,17 @@ class MultiProviderLLMService(LLMServiceInterface):
             prompt_parts.append(f"SYSTEM INSTRUCTIONS:\n{system_message}\n")
 
         # 2. Add conversation context (existing functionality enhanced)
-        if context and context.get('conversation_history'):
-            conversation_history = context['conversation_history']
+        if context and context.get("conversation_history"):
+            conversation_history = context["conversation_history"]
             prompt_parts.append("CONVERSATION HISTORY:")
 
             for msg in conversation_history[-5:]:  # Last 5 messages
-                msg_type = msg.get('message_type', 'unknown')
-                content = msg.get('content', '')
+                msg_type = msg.get("message_type", "unknown")
+                content = msg.get("content", "")
 
-                if msg_type == 'user_input':
+                if msg_type == "user_input":
                     prompt_parts.append(f"User: {content}")
-                elif msg_type == 'agent_response':
+                elif msg_type == "agent_response":
                     prompt_parts.append(f"Assistant: {content}")
 
             prompt_parts.append("")  # Empty line separator
@@ -432,18 +445,20 @@ class MultiProviderLLMService(LLMServiceInterface):
         # 4. Add final instruction that respects system message
         if system_message:
             prompt_parts.append(
-                "\nRespond according to your system instructions above, considering the conversation history.")
+                "\nRespond according to your system instructions above, considering the conversation history."
+            )
 
         return "\n".join(prompt_parts)
+
     def _build_context_aware_prompt(self, prompt: str, context: Dict[str, Any] = None) -> str:
         """🔥 NEW: Build context-aware prompt that preserves conversation history across provider switches"""
         if not context:
             return prompt
 
         # Extract conversation history from context
-        conversation_history = context.get('conversation_history', [])
-        conversation_id = context.get('conversation_id')
-        user_id = context.get('user_id')
+        conversation_history = context.get("conversation_history", [])
+        conversation_id = context.get("conversation_id")
+        user_id = context.get("user_id")
 
         if not conversation_history:
             return prompt
@@ -453,13 +468,13 @@ class MultiProviderLLMService(LLMServiceInterface):
         context_lines.append("# Previous Conversation Context:")
 
         for msg in conversation_history[-5:]:  # Last 5 messages for context
-            msg_type = msg.get('message_type', 'unknown')
-            content = msg.get('content', '')
-            timestamp = msg.get('timestamp', '')
+            msg_type = msg.get("message_type", "unknown")
+            content = msg.get("content", "")
+            timestamp = msg.get("timestamp", "")
 
-            if msg_type == 'user_input':
+            if msg_type == "user_input":
                 context_lines.append(f"User: {content}")
-            elif msg_type == 'agent_response':
+            elif msg_type == "agent_response":
                 context_lines.append(f"Assistant: {content}")
 
         context_lines.append("")
@@ -471,7 +486,7 @@ class MultiProviderLLMService(LLMServiceInterface):
         enhanced_prompt = "\n".join(context_lines)
 
         # 🔥 CRITICAL: Log provider switches with context preservation
-        if hasattr(self, '_last_provider') and self._last_provider != self.current_provider:
+        if hasattr(self, "_last_provider") and self._last_provider != self.current_provider:
             logging.info(f"🔄 Provider switched: {self._last_provider} → {self.current_provider}")
             logging.info(f"🧠 Context preserved: {len(conversation_history)} messages in history")
 
@@ -479,12 +494,13 @@ class MultiProviderLLMService(LLMServiceInterface):
 
         return enhanced_prompt
 
-    async def generate_response_stream(self, prompt: str, context: Dict[str, Any] = None, system_message: str = None) -> AsyncIterator[str]:
+    async def generate_response_stream(
+        self, prompt: str, context: Dict[str, Any] = None, system_message: str = None
+    ) -> AsyncIterator[str]:
         """Generate a streaming response - FIXED: Preserves context across provider switches"""
         if not self.current_llm:
             raise RuntimeError("No LLM provider available")
 
-
         final_prompt = self._build_system_aware_prompt(prompt, context, system_message)
 
         async def _generate_stream():
@@ -513,15 +529,16 @@ class MultiProviderLLMService(LLMServiceInterface):
         except Exception as e:
             raise RuntimeError(f"Failed to generate streaming response: {str(e)}")
 
-    async def query_knowledge_base(self, query: str, kb_name: str, context: Dict[str, Any] = None) -> tuple[
-        str, List[Dict]]:
+    async def query_knowledge_base(
+        self, query: str, kb_name: str, context: Dict[str, Any] = None
+    ) -> tuple[str, List[Dict]]:
         """Query a knowledge base (placeholder implementation)"""
         # This would integrate with your actual knowledge base system
         response = await self.generate_response(
             f"Based on the knowledge base '{kb_name}', answer: {query}"
         )
 
-        sources = [{'source': f'{kb_name}_knowledge_base', 'relevance_score': 0.9}]
+        sources = [{"source": f"{kb_name}_knowledge_base", "relevance_score": 0.9}]
         return response, sources
 
     def get_current_provider(self) -> str:
@@ -530,20 +547,27 @@ class MultiProviderLLMService(LLMServiceInterface):
 
     def get_available_providers(self) -> List[str]:
         """Get list of available provider names"""
-        return [name for name, config in self.provider_tracker.providers.items()
-                if self.provider_tracker.is_provider_available(name)]
+        return [
+            name
+            for name, config in self.provider_tracker.providers.items()
+            if self.provider_tracker.is_provider_available(name)
+        ]
 
     def get_provider_stats(self) -> Dict[str, Dict[str, Any]]:
         """Get statistics for all providers"""
         stats = {}
         for name, config in self.provider_tracker.providers.items():
             stats[name] = {
-                'priority': config.priority,
-                'request_count': config.request_count,
-                'error_count': config.error_count,
-                'is_available': config.is_available,
-                'last_request_time': config.last_request_time.isoformat() if config.last_request_time else None,
-                'last_error_time': config.last_error_time.isoformat() if config.last_error_time else None
+                "priority": config.priority,
+                "request_count": config.request_count,
+                "error_count": config.error_count,
+                "is_available": config.is_available,
+                "last_request_time": (
+                    config.last_request_time.isoformat() if config.last_request_time else None
+                ),
+                "last_error_time": (
+                    config.last_error_time.isoformat() if config.last_error_time else None
+                ),
             }
         return stats
 
@@ -552,25 +576,25 @@ class MultiProviderLLMService(LLMServiceInterface):
         try:
             # Use Anthropic's streaming API
             async for chunk in self.current_llm.astream(prompt):
-                if hasattr(chunk, 'content') and chunk.content:
+                if hasattr(chunk, "content") and chunk.content:
                     yield chunk.content
-                elif hasattr(chunk, 'text') and chunk.text:
+                elif hasattr(chunk, "text") and chunk.text:
                     yield chunk.text
                 else:
                     # For AIMessageChunk objects, extract content properly
                     content = str(chunk)
-                    if content and content != 'None' and not content.startswith('<bound method'):
+                    if content and content != "None" and not content.startswith("<bound method"):
                         yield content
         except Exception as e:
             # Fallback for older Anthropic client versions
             try:
                 async for chunk in self.current_llm.astream(prompt):
-                    if hasattr(chunk, 'content') and chunk.content:
+                    if hasattr(chunk, "content") and chunk.content:
                         yield chunk.content
             except:
                 # Non-streaming fallback
                 response = await self.current_llm.ainvoke(prompt)
-                yield response.content if hasattr(response, 'content') else str(response)
+                yield response.content if hasattr(response, "content") else str(response)
 
     async def _stream_openai(self, prompt: str) -> AsyncIterator[str]:
         """Stream from OpenAI GPT"""
@@ -578,26 +602,28 @@ class MultiProviderLLMService(LLMServiceInterface):
             # Use OpenAI's streaming API
             async for chunk in self.current_llm.astream(prompt):
                 # Handle different chunk types properly
-                if hasattr(chunk, 'content'):
+                if hasattr(chunk, "content"):
                     if isinstance(chunk.content, str) and chunk.content:
                         yield chunk.content
-                    elif hasattr(chunk.content, 'text') and chunk.content.text:
+                    elif hasattr(chunk.content, "text") and chunk.content.text:
                         yield chunk.content.text
-                elif hasattr(chunk, 'text') and chunk.text:
+                elif hasattr(chunk, "text") and chunk.text:
                     yield chunk.text
                 else:
                     # Extract content from AIMessageChunk properly
                     content_str = str(chunk)
-                    if (content_str and
-                            content_str != 'None' and
-                            not content_str.startswith('<bound method') and
-                            not content_str.startswith('AIMessageChunk')):
+                    if (
+                        content_str
+                        and content_str != "None"
+                        and not content_str.startswith("<bound method")
+                        and not content_str.startswith("AIMessageChunk")
+                    ):
                         yield content_str
         except Exception as e:
             # Fallback for older OpenAI client versions
             try:
                 response = await self.current_llm.ainvoke(prompt)
-                yield response.content if hasattr(response, 'content') else str(response)
+                yield response.content if hasattr(response, "content") else str(response)
             except Exception as e2:
                 yield f"OpenAI streaming error: {str(e2)}"
 
@@ -605,20 +631,24 @@ class MultiProviderLLMService(LLMServiceInterface):
         """Stream from AWS Bedrock"""
         try:
             # Bedrock streaming might not be available in all versions
-            if hasattr(self.current_llm, 'astream'):
+            if hasattr(self.current_llm, "astream"):
                 async for chunk in self.current_llm.astream(prompt):
-                    if hasattr(chunk, 'content') and chunk.content:
+                    if hasattr(chunk, "content") and chunk.content:
                         yield chunk.content
-                    elif hasattr(chunk, 'text') and chunk.text:
+                    elif hasattr(chunk, "text") and chunk.text:
                         yield chunk.text
                     else:
                         content = str(chunk)
-                        if content and content != 'None' and not content.startswith('<bound method'):
+                        if (
+                            content
+                            and content != "None"
+                            and not content.startswith("<bound method")
+                        ):
                             yield content
             else:
                 # Non-streaming fallback for Bedrock
                 response = await self.current_llm.ainvoke(prompt)
-                yield response.content if hasattr(response, 'content') else str(response)
+                yield response.content if hasattr(response, "content") else str(response)
         except Exception as e:
             # Bedrock fallback
             try:
@@ -628,8 +658,9 @@ class MultiProviderLLMService(LLMServiceInterface):
                 yield f"Bedrock streaming error: {str(e)}"
 
 
-def create_multi_provider_llm_service(config_data: Dict[str, Any] = None,
-                                      preferred_provider: str = "openai") -> MultiProviderLLMService:
+def create_multi_provider_llm_service(
+    config_data: Dict[str, Any] = None, preferred_provider: str = "openai"
+) -> MultiProviderLLMService:
     """
     Create a multi-provider LLM service with configuration from YAML.
 
@@ -640,4 +671,4 @@ def create_multi_provider_llm_service(config_data: Dict[str, Any] = None,
     Returns:
         MultiProviderLLMService instance
     """
-    return MultiProviderLLMService(config_data, preferred_provider)
\ No newline at end of file
+    return MultiProviderLLMService(config_data, preferred_provider)
