@@ -4,23 +4,23 @@ Agent Service for managing agent sessions and message processing - UPDATED WITH
 """
 
 import asyncio
-import uuid
-import time
 import logging
-from typing import Dict, List, Any, Optional
+import time
+import uuid
 from datetime import datetime, timedelta
+from typing import Any, Dict, List, Optional
 
-from ..core.base import AgentRole, AgentMessage, MessageType, ExecutionContext
-from ..core.memory import create_redis_memory_manager
-from ..core.llm import create_multi_provider_llm_service
 from ..config.loader import (
-    load_config,
-    get_config_section,
-    validate_agent_capabilities,
+    get_available_agent_type_names,
     get_available_agent_types,
+    get_config_section,
     get_enabled_capabilities,
-    get_available_agent_type_names
+    load_config,
+    validate_agent_capabilities,
 )
+from ..core.base import AgentMessage, AgentRole, ExecutionContext, MessageType
+from ..core.llm import create_multi_provider_llm_service
+from ..core.memory import create_redis_memory_manager
 from .factory import AgentFactory
 
 
@@ -31,15 +31,17 @@ class AgentSession:
         # Load configuration from YAML
         self.config = load_config()
         self.session_id = session_id
-        self.redis_config = get_config_section('redis', self.config)
-        self.llm_config = get_config_section('llm', self.config)
-        self.service_config = self.config.get('service', {})
+        self.redis_config = get_config_section("redis", self.config)
+        self.llm_config = get_config_section("llm", self.config)
+        self.service_config = self.config.get("service", {})
 
         # Use centralized capability checking
         self.capabilities = validate_agent_capabilities(self.config)
         self.available_agent_types = get_available_agent_types(self.config)
 
-        self.preferred_llm_provider = preferred_llm_provider or self.llm_config.get('preferred_provider', 'openai')
+        self.preferred_llm_provider = preferred_llm_provider or self.llm_config.get(
+            "preferred_provider", "openai"
+        )
         self.agents = {}
         self.proxy_agent = None
         self.created_at = datetime.now()
@@ -47,7 +49,7 @@ class AgentSession:
         self.message_count = 0
 
         # Setup logging
-        log_level = self.service_config.get('log_level', 'INFO')
+        log_level = self.service_config.get("log_level", "INFO")
         self.logger = logging.getLogger(f"AgentSession-{session_id[:8]}")
         self.logger.setLevel(getattr(logging, log_level))
 
@@ -61,10 +63,11 @@ class AgentSession:
         """Initialize the LLM service"""
         try:
             self.llm_service = create_multi_provider_llm_service(
-                config_data=self.llm_config,
-                preferred_provider=self.preferred_llm_provider
+                config_data=self.llm_config, preferred_provider=self.preferred_llm_provider
+            )
+            self.logger.info(
+                f"LLM service initialized with provider: {self.llm_service.get_current_provider()}"
             )
-            self.logger.info(f"LLM service initialized with provider: {self.llm_service.get_current_provider()}")
         except Exception as e:
             self.logger.error(f"Failed to initialize LLM service: {e}")
             raise e
@@ -76,141 +79,143 @@ class AgentSession:
         assistant_id = f"assistant_{self.session_id}"
         assistant_memory = create_redis_memory_manager(assistant_id, self.redis_config)
 
-        self.agents['assistant'] = AgentFactory.create_agent(
+        self.agents["assistant"] = AgentFactory.create_agent(
             role=AgentRole.ASSISTANT,
             agent_id=assistant_id,
             memory_manager=assistant_memory,
             llm_service=self.llm_service,
-            config=self.config
+            config=self.config,
         )
 
         # Code Executor Agent (if enabled)
-        if self.capabilities.get('code_execution', False):
+        if self.capabilities.get("code_execution", False):
             executor_id = f"executor_{self.session_id}"
             executor_memory = create_redis_memory_manager(executor_id, self.redis_config)
 
-            self.agents['executor'] = AgentFactory.create_agent(
+            self.agents["executor"] = AgentFactory.create_agent(
                 role=AgentRole.CODE_EXECUTOR,
                 agent_id=executor_id,
                 memory_manager=executor_memory,
                 llm_service=self.llm_service,
-                config=self.config
+                config=self.config,
             )
 
         # Create specialized agents based on enabled capabilities
 
         # Web Search Agent (if enabled)
-        if self.capabilities.get('web_search', False):
+        if self.capabilities.get("web_search", False):
             search_id = f"websearch_{self.session_id}"
             search_memory = create_redis_memory_manager(search_id, self.redis_config)
 
             try:
                 from ..agents.web_search import WebSearchAgent
-                self.agents['web_search'] = WebSearchAgent(
-                    agent_id=search_id,
-                    memory_manager=search_memory,
-                    llm_service=self.llm_service
+
+                self.agents["web_search"] = WebSearchAgent(
+                    agent_id=search_id, memory_manager=search_memory, llm_service=self.llm_service
                 )
                 self.logger.info("Created WebSearchAgent")
             except Exception as e:
                 self.logger.error(f"Failed to create WebSearchAgent: {e}")
 
         # Knowledge Base Agent (if enabled)
-        if self.capabilities.get('knowledge_base', False):
+        if self.capabilities.get("knowledge_base", False):
             kb_id = f"knowledge_{self.session_id}"
             kb_memory = create_redis_memory_manager(kb_id, self.redis_config)
 
             try:
                 from ..agents.knowledge_base import KnowledgeBaseAgent
-                self.agents['knowledge_base'] = KnowledgeBaseAgent(
-                    agent_id=kb_id,
-                    memory_manager=kb_memory,
-                    llm_service=self.llm_service
+
+                self.agents["knowledge_base"] = KnowledgeBaseAgent(
+                    agent_id=kb_id, memory_manager=kb_memory, llm_service=self.llm_service
                 )
                 self.logger.info("Created KnowledgeBaseAgent")
             except Exception as e:
                 self.logger.error(f"Failed to create KnowledgeBaseAgent: {e}")
 
         # Web Scraper Agent (if enabled)
-        if self.capabilities.get('web_scraping', False):
+        if self.capabilities.get("web_scraping", False):
             scraper_id = f"webscraper_{self.session_id}"
             scraper_memory = create_redis_memory_manager(scraper_id, self.redis_config)
 
             try:
                 from ..agents.web_scraper import WebScraperAgent
-                self.agents['web_scraper'] = WebScraperAgent(
-                    agent_id=scraper_id,
-                    memory_manager=scraper_memory,
-                    llm_service=self.llm_service
+
+                self.agents["web_scraper"] = WebScraperAgent(
+                    agent_id=scraper_id, memory_manager=scraper_memory, llm_service=self.llm_service
                 )
                 self.logger.info("Created WebScraperAgent")
             except Exception as e:
                 self.logger.error(f"Failed to create WebScraperAgent: {e}")
 
         # Media Editor Agent (if enabled)
-        if self.capabilities.get('media_editor', False):
+        if self.capabilities.get("media_editor", False):
             media_id = f"mediaeditor_{self.session_id}"
             media_memory = create_redis_memory_manager(media_id, self.redis_config)
 
             try:
                 from ..agents.media_editor import MediaEditorAgent
-                self.agents['media_editor'] = MediaEditorAgent(
-                    agent_id=media_id,
-                    memory_manager=media_memory,
-                    llm_service=self.llm_service
+
+                self.agents["media_editor"] = MediaEditorAgent(
+                    agent_id=media_id, memory_manager=media_memory, llm_service=self.llm_service
                 )
                 self.logger.info("Created MediaEditorAgent")
             except Exception as e:
                 self.logger.error(f"Failed to create MediaEditorAgent: {e}")
 
         # YouTube Download Agent (if enabled)
-        if self.capabilities.get('youtube_download', False):
+        if self.capabilities.get("youtube_download", False):
             youtube_id = f"youtube_{self.session_id}"
             youtube_memory = create_redis_memory_manager(youtube_id, self.redis_config)
 
             try:
                 from ..agents.youtube_download import YouTubeDownloadAgent
-                self.agents['youtube_download'] = YouTubeDownloadAgent(
-                    agent_id=youtube_id,
-                    memory_manager=youtube_memory,
-                    llm_service=self.llm_service
+
+                self.agents["youtube_download"] = YouTubeDownloadAgent(
+                    agent_id=youtube_id, memory_manager=youtube_memory, llm_service=self.llm_service
                 )
                 self.logger.info("Created YouTubeDownloadAgent")
             except Exception as e:
                 self.logger.error(f"Failed to create YouTubeDownloadAgent: {e}")
 
-        if self.capabilities.get('moderator', False):
+        if self.capabilities.get("moderator", False):
             moderator_id = f"moderator_{self.session_id}"
             moderator_memory = create_redis_memory_manager(moderator_id, self.redis_config)
 
             try:
                 from ..agents.moderator import ModeratorAgent
-                self.agents['moderator'] = ModeratorAgent(
+
+                self.agents["moderator"] = ModeratorAgent(
                     agent_id=moderator_id,
                     memory_manager=moderator_memory,
-                    llm_service=self.llm_service
+                    llm_service=self.llm_service,
                 )
                 self.logger.info("Created ModeratorAgent")
             except Exception as e:
                 self.logger.error(f"Failed to create ModeratorAgent: {e}")
 
         # Fallback: Create a general researcher agent if no specialized agents were created
-        specialized_agents = ['web_search', 'knowledge_base', 'web_scraper', 'media_editor', 'youtube_download']
+        specialized_agents = [
+            "web_search",
+            "knowledge_base",
+            "web_scraper",
+            "media_editor",
+            "youtube_download",
+        ]
         if not any(key in self.agents for key in specialized_agents):
             researcher_id = f"researcher_{self.session_id}"
             researcher_memory = create_redis_memory_manager(researcher_id, self.redis_config)
 
-            self.agents['researcher'] = AgentFactory.create_agent(
+            self.agents["researcher"] = AgentFactory.create_agent(
                 role=AgentRole.RESEARCHER,
                 agent_id=researcher_id,
                 memory_manager=researcher_memory,
                 llm_service=self.llm_service,
-                config=self.config
+                config=self.config,
             )
             self.logger.info("Created fallback researcher agent")
 
         # Proxy Agent (if enabled)
-        if self.capabilities.get('proxy', True):
+        if self.capabilities.get("proxy", True):
             proxy_id = f"proxy_{self.session_id}"
             proxy_memory = create_redis_memory_manager(proxy_id, self.redis_config)
 
@@ -219,24 +224,26 @@ class AgentSession:
                 agent_id=proxy_id,
                 memory_manager=proxy_memory,
                 llm_service=self.llm_service,
-                config=self.config
+                config=self.config,
             )
 
             # Register all agents with proxy
             for agent in self.agents.values():
                 self.proxy_agent.register_agent(agent)
 
-            self.agents['proxy'] = self.proxy_agent
+            self.agents["proxy"] = self.proxy_agent
 
         enabled_capabilities = get_enabled_capabilities(self.config)
         self.logger.info(f"Initialized session with capabilities: {enabled_capabilities}")
 
-    async def process_message(self,
-                              message_content: str,
-                              user_id: str,
-                              tenant_id: str = "",
-                              conversation_id: str = None,
-                              metadata: Dict[str, Any] = None) -> AgentMessage:
+    async def process_message(
+        self,
+        message_content: str,
+        user_id: str,
+        tenant_id: str = "",
+        conversation_id: str = None,
+        metadata: Dict[str, Any] = None,
+    ) -> AgentMessage:
         """Process a user message through the agent system"""
 
         self.last_activity = datetime.now()
@@ -249,12 +256,16 @@ class AgentSession:
         user_message = AgentMessage(
             id=str(uuid.uuid4()),
             sender_id=f"user_{user_id}",
-            recipient_id=self.proxy_agent.agent_id if self.proxy_agent else list(self.agents.values())[0].agent_id,
+            recipient_id=(
+                self.proxy_agent.agent_id
+                if self.proxy_agent
+                else list(self.agents.values())[0].agent_id
+            ),
             content=message_content,
             message_type=MessageType.USER_INPUT,
             session_id=self.session_id,
             conversation_id=conversation_id,
-            metadata=metadata or {}
+            metadata=metadata or {},
         )
 
         # Create execution context
@@ -264,18 +275,18 @@ class AgentSession:
             user_id=user_id,
             tenant_id=tenant_id,
             metadata={
-                'message_count': self.message_count,
-                'session_age': (datetime.now() - self.created_at).total_seconds(),
-                'enabled_capabilities': get_enabled_capabilities(self.config),
-                'available_agent_types': get_available_agent_type_names(self.config),
-                'config_source': 'agent_config.yaml',
-                **(metadata or {})
-            }
+                "message_count": self.message_count,
+                "session_age": (datetime.now() - self.created_at).total_seconds(),
+                "enabled_capabilities": get_enabled_capabilities(self.config),
+                "available_agent_types": get_available_agent_type_names(self.config),
+                "config_source": "agent_config.yaml",
+                **(metadata or {}),
+            },
         )
 
         try:
             # Process through proxy agent if available, otherwise use assistant
-            target_agent = self.proxy_agent or self.agents.get('assistant')
+            target_agent = self.proxy_agent or self.agents.get("assistant")
 
             if not target_agent:
                 raise RuntimeError("No available agents to process message")
@@ -283,51 +294,59 @@ class AgentSession:
             response = await target_agent.process_message(user_message, context)
 
             # Add session metadata
-            response.metadata.update({
-                'session_id': self.session_id,
-                'message_count': self.message_count,
-                'processing_time': (datetime.now() - self.last_activity).total_seconds(),
-                'enabled_capabilities': get_enabled_capabilities(self.config),
-                'available_agent_types': get_available_agent_type_names(self.config),
-                'config_source': 'agent_config.yaml'
-            })
+            response.metadata.update(
+                {
+                    "session_id": self.session_id,
+                    "message_count": self.message_count,
+                    "processing_time": (datetime.now() - self.last_activity).total_seconds(),
+                    "enabled_capabilities": get_enabled_capabilities(self.config),
+                    "available_agent_types": get_available_agent_type_names(self.config),
+                    "config_source": "agent_config.yaml",
+                }
+            )
 
-            self.logger.debug(f"Processed message {self.message_count} in conversation {conversation_id}")
+            self.logger.debug(
+                f"Processed message {self.message_count} in conversation {conversation_id}"
+            )
             return response
 
         except Exception as e:
             self.logger.error(f"Error processing message: {e}")
             error_response = AgentMessage(
                 id=str(uuid.uuid4()),
-                sender_id=target_agent.agent_id if 'target_agent' in locals() else "system",
+                sender_id=target_agent.agent_id if "target_agent" in locals() else "system",
                 recipient_id=user_message.sender_id,
                 content=f"I encountered an error processing your request: {str(e)}",
                 message_type=MessageType.ERROR,
                 session_id=self.session_id,
                 conversation_id=conversation_id,
-                metadata={'error': str(e), 'message_count': self.message_count, 'config_source': 'agent_config.yaml'}
+                metadata={
+                    "error": str(e),
+                    "message_count": self.message_count,
+                    "config_source": "agent_config.yaml",
+                },
             )
             return error_response
 
     def get_session_stats(self) -> Dict[str, Any]:
         """Get session statistics"""
         return {
-            'session_id': self.session_id,
-            'created_at': self.created_at.isoformat(),
-            'last_activity': self.last_activity.isoformat(),
-            'message_count': self.message_count,
-            'session_age_seconds': (datetime.now() - self.created_at).total_seconds(),
-            'agent_count': len(self.agents),
-            'available_agents': list(self.agents.keys()),
-            'enabled_capabilities': get_enabled_capabilities(self.config),
-            'available_agent_types': get_available_agent_type_names(self.config),
-            'llm_provider': self.llm_service.get_current_provider() if self.llm_service else None,
-            'config_source': 'agent_config.yaml',
-            'redis_config': {
-                'host': self.redis_config.get('host'),
-                'port': self.redis_config.get('port'),
-                'db': self.redis_config.get('db')
-            }
+            "session_id": self.session_id,
+            "created_at": self.created_at.isoformat(),
+            "last_activity": self.last_activity.isoformat(),
+            "message_count": self.message_count,
+            "session_age_seconds": (datetime.now() - self.created_at).total_seconds(),
+            "agent_count": len(self.agents),
+            "available_agents": list(self.agents.keys()),
+            "enabled_capabilities": get_enabled_capabilities(self.config),
+            "available_agent_types": get_available_agent_type_names(self.config),
+            "llm_provider": self.llm_service.get_current_provider() if self.llm_service else None,
+            "config_source": "agent_config.yaml",
+            "redis_config": {
+                "host": self.redis_config.get("host"),
+                "port": self.redis_config.get("port"),
+                "db": self.redis_config.get("db"),
+            },
         }
 
 
@@ -339,18 +358,20 @@ class AgentService:
 
         # Load configuration from YAML
         self.config = load_config()
-        self.redis_config = get_config_section('redis', self.config)
-        self.llm_config = get_config_section('llm', self.config)
-        self.service_config = self.config.get('service', {})
+        self.redis_config = get_config_section("redis", self.config)
+        self.llm_config = get_config_section("llm", self.config)
+        self.service_config = self.config.get("service", {})
 
         # Use centralized capability checking
         self.capabilities = validate_agent_capabilities(self.config)
         self.available_agent_types = get_available_agent_types(self.config)
 
-        self.preferred_llm_provider = preferred_llm_provider or self.llm_config.get('preferred_provider', 'openai')
+        self.preferred_llm_provider = preferred_llm_provider or self.llm_config.get(
+            "preferred_provider", "openai"
+        )
         self.sessions: Dict[str, AgentSession] = {}
-        self.session_timeout = self.service_config.get('session_timeout', 3600)
-        self.max_sessions = self.service_config.get('max_sessions', 100)
+        self.session_timeout = self.service_config.get("session_timeout", 3600)
+        self.max_sessions = self.service_config.get("max_sessions", 100)
 
         # Setup logging
         self.logger = logging.getLogger("AgentService")
@@ -365,17 +386,17 @@ class AgentService:
 
     def _setup_logging(self):
         """Setup logging configuration"""
-        log_level = self.service_config.get('log_level', 'INFO')
-        log_to_file = self.service_config.get('log_to_file', False)
+        log_level = self.service_config.get("log_level", "INFO")
+        log_to_file = self.service_config.get("log_to_file", False)
 
         handlers = [logging.StreamHandler()]
         if log_to_file:
-            handlers.append(logging.FileHandler('agent_service.log'))
+            handlers.append(logging.FileHandler("agent_service.log"))
 
         logging.basicConfig(
             level=getattr(logging, log_level),
-            format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
-            handlers=handlers
+            format="%(asctime)s - %(name)s - %(levelname)s - %(message)s",
+            handlers=handlers,
         )
 
     def create_session(self, session_id: str = None, preferred_llm_provider: str = None) -> str:
@@ -397,7 +418,7 @@ class AgentService:
         try:
             session = AgentSession(
                 session_id=session_id,
-                preferred_llm_provider=preferred_llm_provider or self.preferred_llm_provider
+                preferred_llm_provider=preferred_llm_provider or self.preferred_llm_provider,
             )
 
             self.sessions[session_id] = session
@@ -410,13 +431,15 @@ class AgentService:
             self.logger.error(f"Failed to create session {session_id}: {e}")
             raise
 
-    async def process_message(self,
-                              message: str,
-                              session_id: str,
-                              user_id: str,
-                              tenant_id: str = "",
-                              conversation_id: str = None,
-                              metadata: Dict[str, Any] = None) -> Dict[str, Any]:
+    async def process_message(
+        self,
+        message: str,
+        session_id: str,
+        user_id: str,
+        tenant_id: str = "",
+        conversation_id: str = None,
+        metadata: Dict[str, Any] = None,
+    ) -> Dict[str, Any]:
         """Process a user message through the agent system"""
 
         start_time = time.time()
@@ -434,26 +457,26 @@ class AgentService:
                 user_id=user_id,
                 tenant_id=tenant_id,
                 conversation_id=conversation_id,
-                metadata=metadata
+                metadata=metadata,
             )
 
             self.total_messages_processed += 1
             processing_time = time.time() - start_time
 
             return {
-                'success': True,
-                'response': response.content,
-                'agent_id': response.sender_id,
-                'message_id': response.id,
-                'conversation_id': response.conversation_id,
-                'session_id': session_id,
-                'metadata': response.metadata,
-                'timestamp': response.timestamp.isoformat(),
-                'processing_time': processing_time,
-                'message_count': session.message_count,
-                'enabled_capabilities': get_enabled_capabilities(self.config),
-                'available_agent_types': get_available_agent_type_names(self.config),
-                'config_source': 'agent_config.yaml'
+                "success": True,
+                "response": response.content,
+                "agent_id": response.sender_id,
+                "message_id": response.id,
+                "conversation_id": response.conversation_id,
+                "session_id": session_id,
+                "metadata": response.metadata,
+                "timestamp": response.timestamp.isoformat(),
+                "processing_time": processing_time,
+                "message_count": session.message_count,
+                "enabled_capabilities": get_enabled_capabilities(self.config),
+                "available_agent_types": get_available_agent_type_names(self.config),
+                "config_source": "agent_config.yaml",
             }
 
         except Exception as e:
@@ -461,12 +484,12 @@ class AgentService:
             self.logger.error(f"Error processing message: {e}")
 
             return {
-                'success': False,
-                'error': str(e),
-                'session_id': session_id,
-                'timestamp': datetime.now().isoformat(),
-                'processing_time': processing_time,
-                'config_source': 'agent_config.yaml'
+                "success": False,
+                "error": str(e),
+                "session_id": session_id,
+                "timestamp": datetime.now().isoformat(),
+                "processing_time": processing_time,
+                "config_source": "agent_config.yaml",
             }
 
     def get_service_stats(self) -> Dict[str, Any]:
@@ -475,67 +498,73 @@ class AgentService:
         uptime = current_time - self.start_time
 
         return {
-            'service_status': 'healthy',
-            'uptime_seconds': uptime.total_seconds(),
-            'active_sessions': len(self.sessions),
-            'total_sessions_created': self.total_sessions_created,
-            'total_messages_processed': self.total_messages_processed,
-            'enabled_capabilities': get_enabled_capabilities(self.config),
-            'available_agent_types': self.available_agent_types,
-            'available_agent_type_names': get_available_agent_type_names(self.config),
-            'config_source': 'agent_config.yaml',
-            'configuration_summary': {
-                'redis_host': self.redis_config.get('host'),
-                'redis_port': self.redis_config.get('port'),
-                'llm_provider': self.preferred_llm_provider,
-                'max_sessions': self.max_sessions,
-                'session_timeout': self.session_timeout,
-                'log_level': self.service_config.get('log_level', 'INFO')
+            "service_status": "healthy",
+            "uptime_seconds": uptime.total_seconds(),
+            "active_sessions": len(self.sessions),
+            "total_sessions_created": self.total_sessions_created,
+            "total_messages_processed": self.total_messages_processed,
+            "enabled_capabilities": get_enabled_capabilities(self.config),
+            "available_agent_types": self.available_agent_types,
+            "available_agent_type_names": get_available_agent_type_names(self.config),
+            "config_source": "agent_config.yaml",
+            "configuration_summary": {
+                "redis_host": self.redis_config.get("host"),
+                "redis_port": self.redis_config.get("port"),
+                "llm_provider": self.preferred_llm_provider,
+                "max_sessions": self.max_sessions,
+                "session_timeout": self.session_timeout,
+                "log_level": self.service_config.get("log_level", "INFO"),
             },
-            'timestamp': current_time.isoformat()
+            "timestamp": current_time.isoformat(),
         }
 
     def health_check(self) -> dict[str, Any]:
         """Comprehensive health check - UPDATED WITH YOUTUBE SUPPORT"""
         health_status: dict[str, Any] = {
-            'service_available': True,
-            'timestamp': datetime.now().isoformat(),
-            'config_source': 'agent_config.yaml'
+            "service_available": True,
+            "timestamp": datetime.now().isoformat(),
+            "config_source": "agent_config.yaml",
         }
 
         try:
             # Test Redis connectivity
             test_memory = create_redis_memory_manager("health_check", self.redis_config)
-            health_status['redis_available'] = True
+            health_status["redis_available"] = True
 
             # Test LLM service
             try:
-                test_llm = create_multi_provider_llm_service(self.llm_config, self.preferred_llm_provider)
-                health_status['llm_service_available'] = True
-                health_status['llm_current_provider'] = test_llm.get_current_provider()
-                health_status['llm_available_providers'] = test_llm.get_available_providers()
+                test_llm = create_multi_provider_llm_service(
+                    self.llm_config, self.preferred_llm_provider
+                )
+                health_status["llm_service_available"] = True
+                health_status["llm_current_provider"] = test_llm.get_current_provider()
+                health_status["llm_available_providers"] = test_llm.get_available_providers()
             except Exception as e:
-                health_status['llm_service_available'] = False
-                health_status['llm_error'] = str(e)
+                health_status["llm_service_available"] = False
+                health_status["llm_error"] = str(e)
 
             # Agent capabilities using centralized checking
-            health_status['enabled_capabilities'] = get_enabled_capabilities(self.config)
-            health_status['available_agent_types'] = self.available_agent_types
-            health_status['available_agent_type_names'] = get_available_agent_type_names(self.config)
+            health_status["enabled_capabilities"] = get_enabled_capabilities(self.config)
+            health_status["available_agent_types"] = self.available_agent_types
+            health_status["available_agent_type_names"] = get_available_agent_type_names(
+                self.config
+            )
 
             # Session health
-            health_status.update({
-                'active_sessions': len(self.sessions),
-                'max_sessions': self.max_sessions,
-                'session_capacity_used': len(self.sessions) / self.max_sessions if self.max_sessions > 0 else 0
-            })
+            health_status.update(
+                {
+                    "active_sessions": len(self.sessions),
+                    "max_sessions": self.max_sessions,
+                    "session_capacity_used": (
+                        len(self.sessions) / self.max_sessions if self.max_sessions > 0 else 0
+                    ),
+                }
+            )
 
         except Exception as e:
-            health_status.update({
-                'service_available': False,
-                'error': str(e),
-                'overall_health': 'unhealthy'
-            })
+            health_status.update(
+                {"service_available": False, "error": str(e), "overall_health": "unhealthy"}
+            )
 
         return health_status
 
@@ -548,8 +577,7 @@ class AgentService:
             session_age = current_time - session.created_at.timestamp()
             last_activity_age = current_time - session.last_activity.timestamp()
 
-            if (session_age > self.session_timeout or
-                    last_activity_age > self.session_timeout):
+            if session_age > self.session_timeout or last_activity_age > self.session_timeout:
                 expired_sessions.append(session_id)
 
         for session_id in expired_sessions:
@@ -583,23 +611,18 @@ def create_agent_service(preferred_llm_provider: str = None) -> AgentService:
     return AgentService(preferred_llm_provider=preferred_llm_provider)
 
 
-async def quick_chat(agent_service: AgentService,
-                     message: str,
-                     user_id: str,
-                     session_id: str = None,
-                     **kwargs) -> str:
+async def quick_chat(
+    agent_service: AgentService, message: str, user_id: str, session_id: str = None, **kwargs
+) -> str:
     """Quick chat interface"""
     if not session_id:
         session_id = str(uuid.uuid4())
 
     result = await agent_service.process_message(
-        message=message,
-        session_id=session_id,
-        user_id=user_id,
-        **kwargs
+        message=message, session_id=session_id, user_id=user_id, **kwargs
     )
 
-    if result['success']:
-        return result['response']
+    if result["success"]:
+        return result["response"]
     else:
-        return f"Error: {result['error']}"
\ No newline at end of file
+        return f"Error: {result['error']}"
